Package: CatPredi
Title: Optimal Categorisation of Continuous Variables in Prediction
        Models
Version: 2.0
Authors@R: c(
    person("Irantzu Barrio", email = "irantzu.barrio@ehu.eus", role = c("aut", "cre")),
    person("Maria Xose Rodriguez-Alvarez", role = "aut"),
    person("Inmaculada Arostegui", role = "ctb"),
    person("Diana Marcela Perez", role = "ctb"))
Description: Allows the user to categorise a continuous predictor variable in a logistic or a Cox proportional hazards regression setting, by maximising the discriminative ability of the model. I Barrio, I Arostegui, MX Rodriguez-Alvarez, JM Quintana (2015) <doi:10.1177/0962280215601873>. I Barrio,  MX Rodriguez-Alvarez, L Meira-Machado, C Esteban, I Arostegui (2017) <https://www.idescat.cat/sort/sort411/41.1.3.barrio-etal.pdf>.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: CPE, doParallel, foreach, ggplot2, graphics, mgcv, rgenoud,
        rms, stats, survival
NeedsCompilation: no
Packaged: 2026-05-06 09:48:40 UTC; leire
Author: Irantzu Barrio [aut, cre],
  Maria Xose Rodriguez-Alvarez [aut],
  Inmaculada Arostegui [ctb],
  Diana Marcela Perez [ctb]
Maintainer: Irantzu Barrio <irantzu.barrio@ehu.eus>
Repository: CRAN
Date/Publication: 2026-05-08 07:42:31 UTC
Built: R 4.6.0; ; 2026-05-08 10:30:36 UTC; unix
