# Generated by roxygen2: do not edit by hand

S3method(plot,catpredi)
S3method(plot,catpredi.survival)
S3method(print,catpredi)
S3method(print,catpredi.survival)
S3method(print,comp.cutpoints)
S3method(print,comp.cutpoints.binary)
S3method(print,comp.cutpoints.survival)
S3method(print,summary.catpredi)
S3method(print,summary.catpredi.survival)
S3method(summary,catpredi)
S3method(summary,catpredi.survival)
export(catpredi)
export(catpredi.survival)
export(comp.cutpoints)
export(comp.cutpoints.survival)
export(compare.AUC.ht)
export(controlcatpredi)
export(controlcatpredi.survival)
importFrom(foreach,"%dopar%")
